@@ -16,12 +16,12 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
-    BackupJobState,
-    BackupVaultEvent,
-    CopyJobState,
-    RecoveryPointStatus,
-    RestoreJobStatus,
-    StorageClass,
+    BackupJobStateType,
+    BackupVaultEventType,
+    CopyJobStateType,
+    RecoveryPointStatusType,
+    RestoreJobStatusType,
+    StorageClassType,
 )
 
 if sys.version_info >= (3, 8):
@@ -117,7 +117,7 @@ BackupJobTypeDef = TypedDict(
         "ResourceArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "State": BackupJobState,
+        "State": BackupJobStateType,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
@@ -347,7 +347,7 @@ CopyJobTypeDef = TypedDict(
         "ResourceArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "State": CopyJobState,
+        "State": CopyJobStateType,
         "StatusMessage": str,
         "BackupSizeInBytes": int,
         "IamRoleArn": str,
@@ -411,7 +411,7 @@ DescribeBackupJobOutputTypeDef = TypedDict(
         "ResourceArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "State": BackupJobState,
+        "State": BackupJobStateType,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
@@ -478,7 +478,7 @@ DescribeRecoveryPointOutputTypeDef = TypedDict(
         "ResourceType": str,
         "CreatedBy": "RecoveryPointCreatorTypeDef",
         "IamRoleArn": str,
-        "Status": RecoveryPointStatus,
+        "Status": RecoveryPointStatusType,
         "CreationDate": datetime,
         "CompletionDate": datetime,
         "BackupSizeInBytes": int,
@@ -486,7 +486,7 @@ DescribeRecoveryPointOutputTypeDef = TypedDict(
         "Lifecycle": "LifecycleTypeDef",
         "EncryptionKeyArn": str,
         "IsEncrypted": bool,
-        "StorageClass": StorageClass,
+        "StorageClass": StorageClassType,
         "LastRestoreTime": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -508,7 +508,7 @@ DescribeRestoreJobOutputTypeDef = TypedDict(
         "RecoveryPointArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "Status": RestoreJobStatus,
+        "Status": RestoreJobStatusType,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
@@ -588,7 +588,7 @@ GetBackupVaultNotificationsOutputTypeDef = TypedDict(
         "BackupVaultName": str,
         "BackupVaultArn": str,
         "SNSTopicArn": str,
-        "BackupVaultEvents": List[BackupVaultEvent],
+        "BackupVaultEvents": List[BackupVaultEventType],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -749,7 +749,7 @@ RecoveryPointByBackupVaultTypeDef = TypedDict(
         "ResourceType": str,
         "CreatedBy": "RecoveryPointCreatorTypeDef",
         "IamRoleArn": str,
-        "Status": RecoveryPointStatus,
+        "Status": RecoveryPointStatusType,
         "CreationDate": datetime,
         "CompletionDate": datetime,
         "BackupSizeInBytes": int,
@@ -767,7 +767,7 @@ RecoveryPointByResourceTypeDef = TypedDict(
     {
         "RecoveryPointArn": str,
         "CreationDate": datetime,
-        "Status": RecoveryPointStatus,
+        "Status": RecoveryPointStatusType,
         "EncryptionKeyArn": str,
         "BackupSizeBytes": int,
         "BackupVaultName": str,
@@ -805,7 +805,7 @@ RestoreJobsListMemberTypeDef = TypedDict(
         "RecoveryPointArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "Status": RestoreJobStatus,
+        "Status": RestoreJobStatusType,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
